Stan Math Library: stan/math/prim/scal/prob/binomial_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

binomial_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_BINOMIAL_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_BINOMIAL_RNG_HPP
3
4 #include <boost/random/binomial_distribution.hpp>
5 #include <boost/random/variate_generator.hpp>
6 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
7 #include <stan/math/prim/scal/err/check_bounded.hpp>
8 #include <stan/math/prim/scal/err/check_finite.hpp>
9 #include <stan/math/prim/scal/err/check_greater_or_equal.hpp>
10 #include <stan/math/prim/scal/err/check_less_or_equal.hpp>
11 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
12 #include <stan/math/prim/scal/fun/constants.hpp>
13 #include <stan/math/prim/scal/fun/inv_logit.hpp>
14 #include <stan/math/prim/scal/fun/log1m.hpp>
15 #include <stan/math/prim/scal/fun/log_inv_logit.hpp>
16 #include <stan/math/prim/scal/fun/multiply_log.hpp>
17 #include <stan/math/prim/scal/fun/value_of.hpp>
18 #include <stan/math/prim/scal/fun/binomial_coefficient_log.hpp>
19 #include <stan/math/prim/scal/fun/lbeta.hpp>
20 #include <stan/math/prim/scal/meta/include_summand.hpp>
21 #include <stan/math/prim/scal/fun/inc_beta.hpp>
22
23
24 namespace stan {
25
26 namespace math {
27
28 template <class RNG>
29 inline int
30 binomial_rng(const int N,
31 const double theta,
32 RNG& rng) {
33 using boost::variate_generator;
34 using boost::binomial_distribution;
35
36 static const char* function("stan::math::binomial_rng");
37
38 using stan::math::check_finite;
39 using stan::math::check_less_or_equal;
40 using stan::math::check_greater_or_equal;
41 using stan::math::check_nonnegative;
42
43 check_nonnegative(function, "Population size parameter", N);
44 check_finite(function, "Probability parameter", theta);
45 check_less_or_equal(function, "Probability parameter", theta, 1.0);
46 check_greater_or_equal(function, "Probability parameter", theta, 0.0);
47
48 variate_generator<RNG&, binomial_distribution<> >
49 binomial_rng(rng, binomial_distribution<>(N, theta));
50 return binomial_rng();
51 }
52
53 }
54 }
55 #endif
stan::math::check_greater_or_equal
bool check_greater_or_equal(const char *function, const char *name, const T_y &y, const T_low &low)
Return true if y is greater or equal than low.
Definition: check_greater_or_equal.hpp:84
stan
Definition: log_sum_exp.hpp:8
binomial_coefficient_log.hpp
include_summand.hpp
multiply_log.hpp
check_nonnegative.hpp
log_inv_logit.hpp
check_less_or_equal.hpp
log1m.hpp
stan::math::check_less_or_equal
bool check_less_or_equal(const char *function, const char *name, const T_y &y, const T_high &high)
Return true if y is less or equal to high.
Definition: check_less_or_equal.hpp:81
check_bounded.hpp
stan::math::check_finite
bool check_finite(const char *function, const char *name, const T_y &y)
Return true if y is finite.
Definition: check_finite.hpp:62
constants.hpp
check_finite.hpp
lbeta.hpp
inc_beta.hpp
stan::math::check_nonnegative
bool check_nonnegative(const char *function, const char *name, const T_y &y)
Return true if y is non-negative.
Definition: check_nonnegative.hpp:66
check_greater_or_equal.hpp
value_of.hpp
inv_logit.hpp
check_consistent_sizes.hpp
stan::math::binomial_rng
int binomial_rng(const int N, const double theta, RNG &rng)
Definition: binomial_rng.hpp:30

[ Stan Home Page ] © 2011–2016, Stan Development Team.